==> haskell-csv-0.1.2-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-csv.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: csv
version: 0.1.2
id: csv-0.1.2-c2fjBQBo4S4ggrGOOVcp4
key: csv-0.1.2-c2fjBQBo4S4ggrGOOVcp4
license: MIT
copyright: Jaap Weel, 2007
maintainer: Jaap Weel <weel@ugcs.caltech.edu>
synopsis: CSV loader and dumper
description:
    CSV loader and dumper
    .
    This library parses and dumps documents that are formatted
    according to RFC 4180, \"The common Format and MIME Type for
    Comma-Separated Values (CSV) Files\". This format is used, among
    many other things, as a lingua franca for spreadsheets, and for
    certain web services.
category: Text
author: Jaap Weel <weel@ugcs.caltech.edu>
exposed: True
indefinite: False
exposed-modules:
    Text.CSV
abi: 4427d68d19560e7a16e9848c471ef872
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/csv-0.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/csv-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/csv-0.1.2
hs-libraries: HScsv-0.1.2-c2fjBQBo4S4ggrGOOVcp4
depends:
    base-4.10.1.0 filepath-1.4.1.2
    parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
haddock-interfaces: /usr/share/doc/haskell-csv/html/csv.haddock
haddock-html: /usr/share/doc/haskell-csv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-csv-0.1.2-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-csv.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: csv
version: 0.1.2
id: csv-0.1.2-EpTL7zD0nY4Lq2oA3vrN2m
key: csv-0.1.2-EpTL7zD0nY4Lq2oA3vrN2m
license: MIT
copyright: Jaap Weel, 2007
maintainer: Jaap Weel <weel@ugcs.caltech.edu>
author: Jaap Weel <weel@ugcs.caltech.edu>
synopsis: CSV loader and dumper
description:
    CSV loader and dumper
    .
    This library parses and dumps documents that are formatted
    according to RFC 4180, \"The common Format and MIME Type for
    Comma-Separated Values (CSV) Files\". This format is used, among
    many other things, as a lingua franca for spreadsheets, and for
    certain web services.
category: Text
abi: 96eb36dad3db736296feabfd6b1391a1
exposed: True
exposed-modules:
    Text.CSV
import-dirs: /usr/lib/ghc-8.4.3/site-local/csv-0.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/csv-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/csv-0.1.2
hs-libraries: HScsv-0.1.2-EpTL7zD0nY4Lq2oA3vrN2m
depends:
    base-4.11.1.0 filepath-1.4.2 parsec-3.1.13.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
haddock-interfaces: /usr/share/doc/haskell-csv/html/csv.haddock
haddock-html: /usr/share/doc/haskell-csv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
